package com.notificationFramework.notification;

import android.annotation.TargetApi;
import android.app.NotificationChannel;

import android.content.Intent;
import android.graphics.Color;
import android.media.RingtoneManager;
import android.os.IBinder;
import android.support.annotation.Nullable;
import android.support.v4.app.NotificationCompat;

import com.notificationFramework.sedentary.frontEnd.R;


/**
 * Created by Peter De Jonckheere on 09/01/2018.
 * <p>
 * The concrete implementation of the Notification class which provides the propertis when the
 * notification is to be sent when the user has been sedentary for a prolonged period of time.
 * </p>
 */

public class SedentaryNotification extends Notification {

    /**
     * Called when the service is started. Uses the Notification implementation of this method.
     *
     * @param intent  the intent used to start the service
     * @param flags   additional information about the start request
     * @param startId the unique start id of this service
     * @return the return value of the Notification implementation of this method
     * @see android.app.Service
     */
    @Override
    public int onStartCommand(Intent intent, int flags, int startId) {
        return super.onStartCommand(intent, flags, startId);
    }

    /**
     * The method which reponds to a bind request for this service.
     *
     * @param intent the intent used to rqeuest binding of this service
     * @return null as no bind requests are required.
     * @see android.app.Service
     */
    @Nullable
    @Override
    public IBinder onBind(Intent intent) {
        return null;
    }


    /**
     * Implementation of the abstract method specified in Notification which adds individual
     * properties to the notification which is to be sent such as the content title and content
     * text.
     *
     * @param builder the NotificationCompat.Builder provided to be altered with unique properties
     * @return the altered version of 'builder'
     */
    protected NotificationCompat.Builder setParameters(NotificationCompat.Builder builder) {
        builder.setSmallIcon(android.R.drawable.btn_star);
        builder.setContentTitle(this.getClass().getSimpleName());
        String notificationText =
                preferences.getString(getString(R.string.daily_goal_text),
                        getString(R.string.default_notification_message));
        if (!(preferences.getBoolean(getString(R.string.goal_met), false))) {
            notificationText = notificationText
                    + " " + String.valueOf((preferences.getInt(getString(R.string.daily_goal_set),
                    getResources().getInteger(R.integer.daily_goal_minutes)))
                    - (preferences.getInt(getString(R.string.daily_progress), 0)))
                    + " minutes to reach your goal!";
        }
        builder.setContentText(notificationText);
        builder.setCategory(NotificationCompat.CATEGORY_ALARM);
        builder.setAutoCancel(true);
        if (preferences.getBoolean(getString(R.string.vibration), false)) {
            builder.setVibrate(new long[]{0, 500});
        } else {

        }
        if (preferences.getBoolean(getString(R.string.audio), false)) {
            builder.setSound(RingtoneManager.getDefaultUri(RingtoneManager.TYPE_NOTIFICATION));
        }
        if (preferences.getBoolean(getString(R.string.led), false)) {
            builder.mNotification.flags |= android.app.Notification.FLAG_SHOW_LIGHTS;
            builder.mNotification.ledARGB = Color.parseColor
                    (preferences.getString(getString(R.string.led_colour), "RED"));
            builder.mNotification.ledOnMS =
                    (preferences.getInt(getString(R.string.led_period), 1)) * 1000;
            builder.mNotification.ledOffMS =
                    (preferences.getInt(getString(R.string.led_period), 1)) * 1000;
        }

        return builder;
    }


    /**
     * Implementation of the abstract method specified in Notification which adds individual
     * properties to the NotificationChannel used if the API level is above 26.
     *
     * @param nc the NotificationChannel to be altered with individual properties
     * @return the altered version of 'nc'
     */
    @TargetApi(26)
    protected NotificationChannel setChannelParameters(NotificationChannel nc) {
        nc.setDescription(this.getClass().getName());
        if (preferences.getBoolean(getString(R.string.vibration), false)) {
            nc.enableVibration(preferences.getBoolean(getString(R.string.vibration), false));
        }
        if (preferences.getBoolean(getString(R.string.led), false)) {
            nc.enableLights(preferences.getBoolean(getString(R.string.led), false));
        }
        if (preferences.getBoolean(getString(R.string.audio), false)) {
        }
        return nc;
    }
}
